@@ -7,6 +7,8 @@ from django.utils import six
 from django.utils.encoding import force_text
 from django.utils.translation import override
 
+from .base import CountriesBase
+
 try:
     import pyuca
 except ImportError:
@@ -15,16 +17,20 @@ except ImportError:
 # Use UCA sorting if it's available.
 if pyuca:
     collator = pyuca.Collator()
-    sort_key = lambda item: collator.sort_key(item[1])
+
+    def sort_key(item):
+        return collator.sort_key(item[1])
 else:
     import unicodedata
     # Cheap and dirty method to sort against ASCII characters only.
-    sort_key = lambda item: (
-        unicodedata.normalize('NFKD', item[1])
-        .encode('ascii', 'ignore').decode('ascii'))
+
+    def sort_key(item):
+        return (
+            unicodedata.normalize('NFKD', item[1])
+            .encode('ascii', 'ignore').decode('ascii'))
 
 
-class Countries(object):
+class Countries(CountriesBase):
     """
     An object containing a list of ISO3166-1 countries.
 
@@ -64,10 +70,10 @@ class Countries(object):
             else:
                 # Local import so that countries aren't loaded into memory
                 # until first used.
-                from django_countries.data import COUNTRIES, COMMON_NAMES
+                from django_countries.data import COUNTRIES
                 self._countries = dict(COUNTRIES)
                 if self.get_option('common_names'):
-                    self._countries.update(COMMON_NAMES)
+                    self._countries.update(self.COMMON_NAMES)
                 override = self.get_option('override')
                 if override:
                     self._countries.update(override)
@@ -109,6 +115,31 @@ class Countries(object):
         if hasattr(self, '_countries'):
             del self._countries
 
+    def translate_pair(self, code):
+        """
+        Force a country to the current activated translation.
+
+        :returns: 2-tuple of ``(code, translated_country_name)``
+        """
+        name = self.countries[code]
+        if code in self.OLD_NAMES:
+            # Check if there's an older translation available if there's no
+            # translation for the newest name.
+            with override(None):
+                source_name = force_text(name)
+            name = force_text(name)
+            if name == source_name:
+                for old_name in self.OLD_NAMES[code]:
+                    with override(None):
+                        source_old_name = force_text(old_name)
+                    old_name = force_text(old_name)
+                    if old_name != source_old_name:
+                        name = old_name
+                        break
+        else:
+            name = force_text(name)
+        return (code, name)
+
     def __iter__(self):
         """
         Iterate through countries, sorted by name.
@@ -130,8 +161,16 @@ class Countries(object):
         countries = self.countries
 
         # Yield countries that should be displayed first.
-        for code in self.countries_first:
-            yield (code, force_text(countries[code]))
+        countries_first = (
+            self.translate_pair(code)
+            for code in self.countries_first
+        )
+
+        if self.get_option('first_sort'):
+            countries_first = sorted(countries_first, key=sort_key)
+
+        for item in countries_first:
+            yield item
 
         if self.countries_first:
             first_break = self.get_option('first_break')
@@ -140,9 +179,9 @@ class Countries(object):
 
         # Force translation before sorting.
         first_repeat = self.get_option('first_repeat')
-        countries = [
-            (code, force_text(name)) for code, name in countries.items()
-            if first_repeat or code not in self.countries_first]
+        countries = (
+            self.translate_pair(code) for code in countries
+            if first_repeat or code not in self.countries_first)
 
         # Return sorted country list.
         for item in sorted(countries, key=sort_key):
@@ -158,10 +197,16 @@ class Countries(object):
         code = force_text(code).upper()
         if code.isdigit():
             lookup_code = int(code)
-            find = lambda alt_codes: alt_codes[1] == lookup_code
+
+            def find(alt_codes):
+                return alt_codes[1] == lookup_code
+
         elif len(code) == 3:
             lookup_code = code
-            find = lambda alt_codes: alt_codes[0] == lookup_code
+
+            def find(alt_codes):
+                return alt_codes[0] == lookup_code
+
         else:
             find = None
         if find:
@@ -181,7 +226,9 @@ class Countries(object):
         If no match is found, returns an empty string.
         """
         code = self.alpha2(code)
-        return self.countries.get(code, '')
+        if code not in self.countries:
+            return ''
+        return self.translate_pair(code)[1]
 
     def by_name(self, country, language='en'):
         """
@@ -191,11 +238,19 @@ class Countries(object):
         Warning: This depends on the quality of the available translations.
 
         If no match is found, returns an empty string.
+
+        ..warning:: Be cautious about relying on this returning a country code
+            (especially with any hard-coded string) since the ISO names of
+            countries may change over time.
         """
         with override(language):
             for code, name in self:
-                if name == country:
+                if name.lower() == country.lower():
                     return code
+                if code in self.OLD_NAMES:
+                    for old_name in self.OLD_NAMES[code]:
+                        if old_name.lower() == country.lower():
+                            return code
         return ''
 
     def alpha3(self, code):
@@ -264,4 +319,5 @@ class Countries(object):
             return list(islice(self.__iter__(), index.start, index.stop,
                                index.step))
 
+
 countries = Countries()
