@@ -1,7 +1,7 @@
 import django.conf
 
 
-class AppSettings(django.conf.BaseSettings):
+class AppSettings(object):
     """
     A holder for app-specific default settings that allows overriding via
     the project's settings.
@@ -93,4 +93,12 @@ class Settings(AppSettings):
     countries.
     """
 
+    COUNTRIES_FIRST_SORT = False
+    """
+    Countries listed in :attr:`COUNTRIES_FIRST` will be alphanumerically
+    sorted based on their translated name instead of relying on their
+    order in :attr:`COUNTRIES_FIRST`.
+    """
+
+
 settings = Settings()
