@@ -19,29 +19,14 @@ from __future__ import unicode_literals
 import glob
 import os
 
+from django_countries.base import CountriesBase
+
 try:
     from django.utils.translation import ugettext_lazy as _
 except ImportError:  # pragma: no cover
     # Allows this module to be executed without Django installed.
-    _ = lambda x: x
-
-COMMON_NAMES = {
-    "BN": _("Brunei"),
-    "BO": _("Bolivia"),
-    "GB": _("United Kingdom"),
-    "IR": _("Iran"),
-    "KP": _("North Korea"),
-    "KR": _("South Korea"),
-    "LA": _("Laos"),
-    "MD": _("Moldova"),
-    "MK": _("Macedonia"),
-    "RU": _("Russia"),
-    "SY": _("Syria"),
-    "TW": _("Taiwan"),
-    "TZ": _("Tanzania"),
-    "VE": _("Venezuela"),
-    "VN": _("Vietnam"),
-}
+    def _(x):
+        return x
 
 # Nicely titled (and translatable) country names.
 COUNTRIES = {
@@ -104,7 +89,7 @@ COUNTRIES = {
     "CU": _("Cuba"),
     "CW": _("Curaçao"),
     "CY": _("Cyprus"),
-    "CZ": _("Czech Republic"),
+    "CZ": _("Czechia"),
     "DK": _("Denmark"),
     "DJ": _("Djibouti"),
     "DM": _("Dominica"),
@@ -628,7 +613,7 @@ def check_flags(verbosity=1):
 
 
 def check_common_names():
-    common_names_missing = set(COMMON_NAMES) - set(COUNTRIES)
+    common_names_missing = set(CountriesBase.COMMON_NAMES) - set(COUNTRIES)
     if common_names_missing:  # pragma: no cover
         print("")
         print(
