@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 from django.test import TestCase
+from django.utils import translation
 
 from django_countries import countries, Countries
 from django_countries.tests import custom_countries
@@ -113,6 +114,18 @@ class TestCountriesObject(BaseTest):
         code = countries.by_name('United States of America')
         self.assertEqual(code, 'US')
 
+    def test_fetch_by_name_case_insensitive(self):
+        code = countries.by_name('United states of America')
+        self.assertEqual(code, 'US')
+
+    def test_fetch_by_name_old(self):
+        code = countries.by_name('Czech Republic')
+        self.assertEqual(code, 'CZ')
+
+    def test_fetch_by_name_old_case_insensitive(self):
+        code = countries.by_name('Czech republic')
+        self.assertEqual(code, 'CZ')
+
     def test_fetch_by_name_i18n(self):
         code = countries.by_name('Estados Unidos', language='es')
         self.assertEqual(code, 'US')
@@ -186,6 +199,33 @@ class CountriesFirstTest(BaseTest):
                            COUNTRIES_FIRST_BREAK='------'):
             self.assertEqual(len(countries), EXPECTED_COUNTRY_COUNT)
 
+    def test_sorted_countries_first_english(self):
+        with self.settings(
+                COUNTRIES_FIRST=['GB', 'AF', 'DK'], COUNTRIES_FIRST_SORT=True):
+            countries_list = list(countries)
+            sorted_codes = [item[0] for item in countries_list[:3]]
+            self.assertEqual(['AF', 'DK', 'GB'], sorted_codes)
+
+    def test_unsorted_countries_first_english(self):
+        with self.settings(
+                COUNTRIES_FIRST=['GB', 'AF', 'DK'],
+                COUNTRIES_FIRST_SORT=False):
+            countries_list = list(countries)
+            unsorted_codes = [item[0] for item in countries_list[:3]]
+            self.assertEqual(['GB', 'AF', 'DK'], unsorted_codes)
+
+    def test_sorted_countries_first_arabic(self):
+        with self.settings(
+                COUNTRIES_FIRST=['GB', 'AF', 'DK'], COUNTRIES_FIRST_SORT=True):
+            lang = translation.get_language()
+            translation.activate('eo')
+            try:
+                countries_list = list(countries)
+                sorted_codes = [item[0] for item in countries_list[:3]]
+                self.assertEqual(['AF', 'GB', 'DK'], sorted_codes)
+            finally:
+                translation.activate(lang)
+
 
 class TestCountriesCustom(BaseTest):
 
